Flag class abstract

Feature flag available to the identity.

Available extensions
Annotations
  • @freezed

Constructors

Flag({String? name, String? value, bool? conditionChanged})
const
factory
Flag.fromDto(ApiFlag dto)
factory
Flag.fromJson(Map<String, dynamic> json)
factory

Properties

conditionChanged bool?
Whether the value for this flag has conditionally changed from the default state.
no setterinherited
copyWith → $FlagCopyWith<Flag>
Create a copy of Flag with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String?
Flag name
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
Value associated with this Flag.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Flag value)) → TResult

Available on Flag, provided by the FlagPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Flag value)?) → TResult?

Available on Flag, provided by the FlagPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Flag value)?, {required TResult orElse()}) → TResult

Available on Flag, provided by the FlagPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? name, String? value, bool? conditionChanged)?, {required TResult orElse()}) → TResult

Available on Flag, provided by the FlagPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Flag to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? name, String? value, bool? conditionChanged)) → TResult

Available on Flag, provided by the FlagPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? name, String? value, bool? conditionChanged)?) → TResult?

Available on Flag, provided by the FlagPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited